@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="gl_ES" version="2.1">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="gl_ES">
 <context>
     <name>DAboutDialog</name>
     <message>
@@ -7,12 +9,12 @@
         <translation>Recoñecementos</translation>
     </message>
     <message>
-        <location filename="../widgets/dapplication.cpp" line="1094"/>
+        <location filename="../widgets/dapplication.cpp" line="1238"/>
         <source>Version: %1</source>
         <translation>Versión: %1</translation>
     </message>
     <message>
-        <location filename="../widgets/dapplication.cpp" line="1098"/>
+        <location filename="../widgets/dapplication.cpp" line="1242"/>
         <source>%1 is released under %2</source>
         <translation>%1 está liberada baixo %2</translation>
     </message>
@@ -20,87 +22,87 @@
 <context>
     <name>DCrumbEdit</name>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="896"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="900"/>
         <source>Black</source>
         <translation>Negro</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="899"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="903"/>
         <source>White</source>
         <translation>Branco</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="902"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="906"/>
         <source>Dark Gray</source>
         <translation>Gris escuro</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="905"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="909"/>
         <source>Gray</source>
         <translation>Gris</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="908"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="912"/>
         <source>Light Gray</source>
         <translation>Gris claro</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="911"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="915"/>
         <source>Red</source>
         <translation>Vermello</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="914"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="918"/>
         <source>Green</source>
         <translation>Verde</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="917"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="921"/>
         <source>Blue</source>
         <translation>Azul</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="920"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="924"/>
         <source>Cyan</source>
         <translation>Ciano</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="923"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="927"/>
         <source>Magenta</source>
         <translation>Maxenta</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="926"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="930"/>
         <source>Yellow</source>
         <translation>Amarelo</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="929"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="933"/>
         <source>Dark Red</source>
         <translation>Vermello escuro</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="932"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="936"/>
         <source>Dark Green</source>
         <translation>Verde escuro</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="935"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="939"/>
         <source>Dark Blue</source>
         <translation>Azul escuro</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="938"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="942"/>
         <source>Dark Cyan</source>
         <translation>Ciano escuro</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="941"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="945"/>
         <source>Dark Magenta</source>
         <translation>Maxenta escuro</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="944"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="948"/>
         <source>Dark Yellow</source>
         <translation>Amarelo escuro</translation>
     </message>
@@ -121,7 +123,7 @@
 <context>
     <name>DKeySequenceEdit</name>
     <message>
-        <location filename="../widgets/dkeysequenceedit.cpp" line="42"/>
+        <location filename="../widgets/dkeysequenceedit.cpp" line="85"/>
         <source>Enter a new shortcut</source>
         <translation>Inserir atallo novo</translation>
     </message>
@@ -152,385 +154,388 @@
 <context>
     <name>DPrintPreviewDialogPrivate</name>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="215"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1117"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="232"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1175"/>
         <source>Advanced</source>
         <translation>Avanzado</translation>
     </message>
-    <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="238"/>
-        <source>Cancel</source>
-        <translation>Cancelar</translation>
-    </message>
-    <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="239"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1508"/>
-        <source>Print</source>
-        <translation>Imprimir</translation>
-    </message>
     <message>
         <location filename="../widgets/dprintpreviewdialog.cpp" line="255"/>
+        <source>Cancel</source>
+        <comment>button</comment>
+        <translation type="unfinished">Cancelar</translation>
+    </message>
+    <message>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="256"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1596"/>
+        <source>Print</source>
+        <comment>button</comment>
+        <translation type="unfinished">Imprimir</translation>
+    </message>
+    <message>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="272"/>
         <source>Basic</source>
         <translation>Básico</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="270"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="287"/>
         <source>Printer</source>
         <translation>Impresora</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="284"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="301"/>
         <source>Copies</source>
         <translation>Copias</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="303"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="321"/>
         <source>Page range</source>
         <translation>Rangos de páxina</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="305"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="323"/>
         <source>All</source>
         <translation>Todo</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="306"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="324"/>
         <source>Current page</source>
         <translation>Páxina actual</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="307"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="325"/>
         <source>Select pages</source>
         <translation>Seleccionar páxinas</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="322"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="340"/>
         <source>Orientation</source>
         <translation>Orientación</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="346"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="364"/>
         <source>Portrait</source>
         <translation>Vertical</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="356"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="374"/>
         <source>Landscape</source>
         <translation>Horizontal</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="384"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="402"/>
         <source>Pages</source>
         <translation>Páxinas</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="394"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="412"/>
         <source>Color mode</source>
         <translation>Modo de cor</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="396"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1478"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1524"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="414"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1553"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1620"/>
         <source>Color</source>
         <translation>Cor</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="396"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1517"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1524"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="414"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1605"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1620"/>
         <source>Grayscale</source>
         <translation>Escala de grises</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="407"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="425"/>
         <source>Margins</source>
         <translation>Marxes</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="409"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
         <source>Narrow (mm)</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="409"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
         <source>Normal (mm)</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="409"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
         <source>Moderate (mm)</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="409"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
         <source>Customize (mm)</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="415"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="433"/>
         <source>Top</source>
         <translation>Superior</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="418"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="436"/>
         <source>Left</source>
         <translation>Esquerda</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="421"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="439"/>
         <source>Bottom</source>
         <translation>Inferior</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="424"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="442"/>
         <source>Right</source>
         <translation>Dereita</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="469"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="487"/>
         <source>Scaling</source>
         <translation>Escalado</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="483"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="501"/>
         <source>Actual size</source>
         <translation>Tamaño actual</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="492"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="510"/>
         <source>Scale</source>
         <translation>Escala</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="523"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="541"/>
         <source>Paper</source>
         <translation>Papel</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="533"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="551"/>
         <source>Paper size</source>
         <translation>Tamaño do papel</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="546"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="564"/>
         <source>Print Layout</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="557"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="575"/>
         <source>Duplex</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="570"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="588"/>
         <source>N-up printing</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="572"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
         <source>2 pages/sheet, 1×2</source>
         <translation>2 páxinas/folla, 1×2</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="572"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
         <source>4 pages/sheet, 2×2</source>
         <translation>4 páxinas/folla, 2×2</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="572"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
         <source>6 pages/sheet, 2×3</source>
         <translation>6 páxinas/folla, 2×3</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="572"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
         <source>9 pages/sheet, 3×3</source>
         <translation>9 páxinas/folla, 3×3</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="572"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
         <source>16 pages/sheet, 4×4</source>
         <translation>16 páxinas/folla, 4×4</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="581"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="599"/>
         <source>Layout direction</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="626"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="644"/>
         <source>Page Order</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="636"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="655"/>
         <source>Collate pages</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="641"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="661"/>
         <source>Print pages in order</source>
         <translation>Imprimir páxinas en orde</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="643"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="663"/>
         <source>Front to back</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="643"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="663"/>
         <source>Back to front</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="667"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="687"/>
         <source>Watermark</source>
         <translation>Marca de auga</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="678"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="698"/>
         <source>Add watermark</source>
         <translation>Engadir marca de auga</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="720"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="740"/>
         <source>Text watermark</source>
         <translation>Texto da marca de auga</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="722"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
         <source>Confidential</source>
         <translation>Confidencial</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="722"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
         <source>Draft</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="722"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
         <source>Sample</source>
         <translation>Exemplo</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="722"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
         <source>Custom</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="730"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="750"/>
         <source>Input your text</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="753"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="773"/>
         <source>Picture watermark</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="774"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="794"/>
         <source>Layout</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="776"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="796"/>
         <source>Tile</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="776"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="796"/>
         <source>Center</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="787"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="807"/>
         <source>Angle</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="803"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="823"/>
         <source>Size</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="824"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="844"/>
         <source>Transparency</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="881"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="901"/>
         <source>Print to PDF</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="882"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="902"/>
         <source>Save as Image</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1113"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1171"/>
         <source>Collapse</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1234"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1241"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1294"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1301"/>
         <source>Flip on short edge</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1237"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1240"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1297"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1300"/>
         <source>Flip on long edge</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1337"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1397"/>
         <source>Input page numbers please</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1340"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1400"/>
         <source>Maximum page number reached</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1343"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1403"/>
         <source>Input English comma please</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1346"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1406"/>
         <source>Input page numbers like this: 1,3,5-7,11-15,18,21</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1483"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1558"/>
         <source>Save</source>
-        <translation type="unfinished"/>
+        <comment>button</comment>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1575"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="2168"/>
+        <source>*.pdf</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1672"/>
         <source>For example, 1,3,5-7,11-15,18,21</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="2061"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="2168"/>
         <source>Save as PDF</source>
         <translation>Gardar como PDF</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="2061"/>
-        <source>PDF file</source>
-        <translation>Ficheiro PDF</translation>
-    </message>
-    <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="2099"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="2207"/>
         <source>Save as image</source>
         <translation>Gardar como imaxe</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="2101"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="2209"/>
         <source>Images</source>
         <translation>Imaxes</translation>
     </message>
@@ -538,20 +543,20 @@
 <context>
     <name>DPrintPreviewWidget</name>
     <message>
-        <location filename="../widgets/dprintpreviewwidget.cpp" line="1250"/>
-        <location filename="../widgets/dprintpreviewwidget.cpp" line="1253"/>
+        <location filename="../widgets/dprintpreviewwidget.cpp" line="1590"/>
+        <location filename="../widgets/dprintpreviewwidget.cpp" line="1593"/>
         <source>Confidential</source>
         <translation>Confidencial</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewwidget.cpp" line="1268"/>
-        <location filename="../widgets/dprintpreviewwidget.cpp" line="1271"/>
+        <location filename="../widgets/dprintpreviewwidget.cpp" line="1608"/>
+        <location filename="../widgets/dprintpreviewwidget.cpp" line="1611"/>
         <source>Draft</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewwidget.cpp" line="1286"/>
-        <location filename="../widgets/dprintpreviewwidget.cpp" line="1289"/>
+        <location filename="../widgets/dprintpreviewwidget.cpp" line="1626"/>
+        <location filename="../widgets/dprintpreviewwidget.cpp" line="1629"/>
         <source>Sample</source>
         <translation>Exemplo</translation>
     </message>
@@ -559,7 +564,7 @@
 <context>
     <name>DSearchEdit</name>
     <message>
-        <location filename="../widgets/dsearchedit.cpp" line="285"/>
+        <location filename="../widgets/dsearchedit.cpp" line="291"/>
         <source>Search</source>
         <translation>Buscar</translation>
     </message>
@@ -598,22 +603,22 @@
 <context>
     <name>DTextEdit</name>
     <message>
-        <location filename="../widgets/dtextedit.cpp" line="155"/>
+        <location filename="../widgets/dtextedit.cpp" line="171"/>
         <source>Stop reading</source>
         <translation>Parar de ler</translation>
     </message>
     <message>
-        <location filename="../widgets/dtextedit.cpp" line="157"/>
+        <location filename="../widgets/dtextedit.cpp" line="173"/>
         <source>Text to Speech</source>
         <translation>De texto a voz</translation>
     </message>
     <message>
-        <location filename="../widgets/dtextedit.cpp" line="180"/>
+        <location filename="../widgets/dtextedit.cpp" line="196"/>
         <source>Translate</source>
         <translation>Traducir</translation>
     </message>
     <message>
-        <location filename="../widgets/dtextedit.cpp" line="202"/>
+        <location filename="../widgets/dtextedit.cpp" line="218"/>
         <source>Speech To Text</source>
         <translation>Da voz ao texto</translation>
     </message>
@@ -621,18 +626,11 @@
 <context>
     <name>PickColorWidget</name>
     <message>
-        <location filename="../widgets/dprintpickcolorwidget.cpp" line="89"/>
+        <location filename="../widgets/dprintpickcolorwidget.cpp" line="109"/>
         <source>Color</source>
         <translation>Cor</translation>
     </message>
 </context>
-<context>
-    <name>PrintPreviewDialog</name>
-    <message>
-        <source>Cancel</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>QLineEdit</name>
     <message>
@@ -649,7 +647,7 @@
         <translation>Sen resultados</translation>
     </message>
     <message>
-        <location filename="../widgets/private/settings/content.cpp" line="330"/>
+        <location filename="../widgets/private/settings/content.cpp" line="331"/>
         <source>Restore Defaults</source>
         <translation>Restaurar predefinidos</translation>
     </message>
@@ -657,7 +655,7 @@
 <context>
     <name>QWidgetTextControl</name>
     <message>
-        <location filename="../widgets/dtextedit.cpp" line="147"/>
+        <location filename="../widgets/dtextedit.cpp" line="163"/>
         <source>Select All</source>
         <translation>Seleccionar todo</translation>
     </message>
@@ -673,39 +671,39 @@
 <context>
     <name>TitleBarMenu</name>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="526"/>
+        <location filename="../widgets/dtitlebar.cpp" line="527"/>
         <source>Theme</source>
         <translation>Tema</translation>
     </message>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="528"/>
+        <location filename="../widgets/dtitlebar.cpp" line="529"/>
         <source>Light Theme</source>
         <translation>Tema claro</translation>
     </message>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="529"/>
+        <location filename="../widgets/dtitlebar.cpp" line="530"/>
         <source>Dark Theme</source>
         <translation>Tema escuro</translation>
     </message>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="530"/>
+        <location filename="../widgets/dtitlebar.cpp" line="531"/>
         <source>System Theme</source>
         <translation>Tema do sistema</translation>
     </message>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="554"/>
+        <location filename="../widgets/dtitlebar.cpp" line="555"/>
         <source>Help</source>
         <translation>Axuda</translation>
     </message>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="561"/>
+        <location filename="../widgets/dtitlebar.cpp" line="563"/>
         <source>About</source>
         <translation>Sobre</translation>
     </message>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="568"/>
+        <location filename="../widgets/dtitlebar.cpp" line="570"/>
         <source>Exit</source>
         <translation>Saír</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
