@@ -7,12 +7,12 @@
         <translation>鸣谢</translation>
     </message>
     <message>
-        <location filename="../widgets/dapplication.cpp" line="1094"/>
+        <location filename="../widgets/dapplication.cpp" line="1238"/>
         <source>Version: %1</source>
         <translation>版本：%1</translation>
     </message>
     <message>
-        <location filename="../widgets/dapplication.cpp" line="1098"/>
+        <location filename="../widgets/dapplication.cpp" line="1242"/>
         <source>%1 is released under %2</source>
         <translation>%1遵循%2协议发布</translation>
     </message>
@@ -20,87 +20,87 @@
 <context>
     <name>DCrumbEdit</name>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="896"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="900"/>
         <source>Black</source>
         <translation>黑色</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="899"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="903"/>
         <source>White</source>
         <translation>白色</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="902"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="906"/>
         <source>Dark Gray</source>
         <translation>深灰色</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="905"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="909"/>
         <source>Gray</source>
         <translation>灰色</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="908"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="912"/>
         <source>Light Gray</source>
         <translation>浅灰色</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="911"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="915"/>
         <source>Red</source>
         <translation>红色</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="914"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="918"/>
         <source>Green</source>
         <translation>绿色</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="917"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="921"/>
         <source>Blue</source>
         <translation>蓝色</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="920"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="924"/>
         <source>Cyan</source>
         <translation>青色</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="923"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="927"/>
         <source>Magenta</source>
         <translation>洋红色</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="926"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="930"/>
         <source>Yellow</source>
         <translation>黄色</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="929"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="933"/>
         <source>Dark Red</source>
         <translation>深红色</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="932"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="936"/>
         <source>Dark Green</source>
         <translation>深绿色</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="935"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="939"/>
         <source>Dark Blue</source>
         <translation>深蓝色</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="938"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="942"/>
         <source>Dark Cyan</source>
         <translation>深青色</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="941"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="945"/>
         <source>Dark Magenta</source>
         <translation>深紫红色</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="944"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="948"/>
         <source>Dark Yellow</source>
         <translation>深黄色</translation>
     </message>
@@ -121,7 +121,7 @@
 <context>
     <name>DKeySequenceEdit</name>
     <message>
-        <location filename="../widgets/dkeysequenceedit.cpp" line="42"/>
+        <location filename="../widgets/dkeysequenceedit.cpp" line="85"/>
         <source>Enter a new shortcut</source>
         <translation>请输入新的快捷键</translation>
     </message>
@@ -152,385 +152,388 @@
 <context>
     <name>DPrintPreviewDialogPrivate</name>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="215"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1117"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="232"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1175"/>
         <source>Advanced</source>
         <translation>高级设置</translation>
     </message>
-    <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="238"/>
-        <source>Cancel</source>
-        <translation>取消</translation>
-    </message>
-    <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="239"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1508"/>
-        <source>Print</source>
-        <translation>打印</translation>
-    </message>
     <message>
         <location filename="../widgets/dprintpreviewdialog.cpp" line="255"/>
+        <source>Cancel</source>
+        <comment>button</comment>
+        <translation>取 消</translation>
+    </message>
+    <message>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="256"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1596"/>
+        <source>Print</source>
+        <comment>button</comment>
+        <translation>打 印</translation>
+    </message>
+    <message>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="272"/>
         <source>Basic</source>
         <translation>基础设置</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="270"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="287"/>
         <source>Printer</source>
         <translation>打印机</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="284"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="301"/>
         <source>Copies</source>
         <translation>打印份数</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="303"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="321"/>
         <source>Page range</source>
         <translation>页码范围</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="305"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="323"/>
         <source>All</source>
         <translation>全部</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="306"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="324"/>
         <source>Current page</source>
         <translation>当前页</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="307"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="325"/>
         <source>Select pages</source>
         <translation>指定页面</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="322"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="340"/>
         <source>Orientation</source>
         <translation>打印方向</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="346"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="364"/>
         <source>Portrait</source>
         <translation>纵向</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="356"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="374"/>
         <source>Landscape</source>
         <translation>横向</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="384"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="402"/>
         <source>Pages</source>
         <translation>页面设置</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="394"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="412"/>
         <source>Color mode</source>
         <translation>色彩</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="396"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1478"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1524"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="414"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1553"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1620"/>
         <source>Color</source>
         <translation>彩色</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="396"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1517"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1524"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="414"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1605"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1620"/>
         <source>Grayscale</source>
         <translation>黑白</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="407"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="425"/>
         <source>Margins</source>
         <translation>页边距</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="409"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
         <source>Narrow (mm)</source>
         <translation>窄 (mm)</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="409"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
         <source>Normal (mm)</source>
         <translation>普通 (mm)</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="409"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
         <source>Moderate (mm)</source>
         <translation>适中 (mm)</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="409"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
         <source>Customize (mm)</source>
         <translation>自定义 (mm)</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="415"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="433"/>
         <source>Top</source>
         <translation>上</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="418"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="436"/>
         <source>Left</source>
         <translation>左</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="421"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="439"/>
         <source>Bottom</source>
         <translation>下</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="424"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="442"/>
         <source>Right</source>
         <translation>右</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="469"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="487"/>
         <source>Scaling</source>
         <translation>缩放</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="483"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="501"/>
         <source>Actual size</source>
         <translation>实际大小</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="492"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="510"/>
         <source>Scale</source>
         <translation>自定义比例</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="523"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="541"/>
         <source>Paper</source>
         <translation>纸张</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="533"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="551"/>
         <source>Paper size</source>
         <translation>纸张大小</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="546"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="564"/>
         <source>Print Layout</source>
         <translation>打印方式</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="557"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="575"/>
         <source>Duplex</source>
         <translation>双面打印</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="570"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="588"/>
         <source>N-up printing</source>
         <translation>并列打印</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="572"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
         <source>2 pages/sheet, 1×2</source>
         <translation>每页2版 1×2</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="572"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
         <source>4 pages/sheet, 2×2</source>
         <translation>每页4版 2×2</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="572"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
         <source>6 pages/sheet, 2×3</source>
         <translation>每页6版 2×3</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="572"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
         <source>9 pages/sheet, 3×3</source>
         <translation>每页9版 3×3</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="572"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
         <source>16 pages/sheet, 4×4</source>
         <translation>每页16版 4×4</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="581"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="599"/>
         <source>Layout direction</source>
         <translation>并打顺序</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="626"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="644"/>
         <source>Page Order</source>
         <translation>打印顺序</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="636"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="655"/>
         <source>Collate pages</source>
         <translation>逐份打印</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="641"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="661"/>
         <source>Print pages in order</source>
         <translation>按顺序打印</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="643"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="663"/>
         <source>Front to back</source>
         <translation>由前向后</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="643"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="663"/>
         <source>Back to front</source>
         <translation>由后向前</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="667"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="687"/>
         <source>Watermark</source>
         <translation>水印</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="678"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="698"/>
         <source>Add watermark</source>
         <translation>添加水印</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="720"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="740"/>
         <source>Text watermark</source>
         <translation>文字水印</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="722"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
         <source>Confidential</source>
         <translation>绝密</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="722"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
         <source>Draft</source>
         <translation>草稿</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="722"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
         <source>Sample</source>
         <translation>样本</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="722"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
         <source>Custom</source>
         <translation>自定义</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="730"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="750"/>
         <source>Input your text</source>
         <translation>请输入自定义水印</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="753"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="773"/>
         <source>Picture watermark</source>
         <translation>图片水印</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="774"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="794"/>
         <source>Layout</source>
         <translation>布局</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="776"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="796"/>
         <source>Tile</source>
         <translation>平铺</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="776"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="796"/>
         <source>Center</source>
         <translation>居中</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="787"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="807"/>
         <source>Angle</source>
         <translation>倾度</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="803"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="823"/>
         <source>Size</source>
         <translation>大小</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="824"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="844"/>
         <source>Transparency</source>
         <translation>透明度</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="881"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="901"/>
         <source>Print to PDF</source>
         <translation>存为PDF</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="882"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="902"/>
         <source>Save as Image</source>
         <translation>另存为图片</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1113"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1171"/>
         <source>Collapse</source>
         <translation>收起</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1234"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1241"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1294"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1301"/>
         <source>Flip on short edge</source>
         <translation>短边翻转</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1237"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1240"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1297"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1300"/>
         <source>Flip on long edge</source>
         <translation>长边翻转</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1337"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1397"/>
         <source>Input page numbers please</source>
         <translation>请输入打印页码</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1340"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1400"/>
         <source>Maximum page number reached</source>
         <translation>超出打印范围</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1343"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1403"/>
         <source>Input English comma please</source>
         <translation>请输入英文逗号</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1346"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1406"/>
         <source>Input page numbers like this: 1,3,5-7,11-15,18,21</source>
         <translation>请输入正确格式，例：1,3,5-7,11-15,18,21</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1483"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1558"/>
         <source>Save</source>
-        <translation>保存</translation>
+        <comment>button</comment>
+        <translation>保 存</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1575"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="2168"/>
+        <source>*.pdf</source>
+        <translation>*.pdf</translation>
+    </message>
+    <message>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1672"/>
         <source>For example, 1,3,5-7,11-15,18,21</source>
         <translation>可输入格式：1,3,5-7,11-15,18,21</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="2061"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="2168"/>
         <source>Save as PDF</source>
         <translation>保存为PDF</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="2061"/>
-        <source>PDF file</source>
-        <translation>PDF文件格式</translation>
-    </message>
-    <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="2099"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="2207"/>
         <source>Save as image</source>
         <translation>保存为图片</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="2101"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="2209"/>
         <source>Images</source>
         <translation>图片文件</translation>
     </message>
@@ -538,20 +541,20 @@
 <context>
     <name>DPrintPreviewWidget</name>
     <message>
-        <location filename="../widgets/dprintpreviewwidget.cpp" line="1250"/>
-        <location filename="../widgets/dprintpreviewwidget.cpp" line="1253"/>
+        <location filename="../widgets/dprintpreviewwidget.cpp" line="1590"/>
+        <location filename="../widgets/dprintpreviewwidget.cpp" line="1593"/>
         <source>Confidential</source>
         <translation>绝密</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewwidget.cpp" line="1268"/>
-        <location filename="../widgets/dprintpreviewwidget.cpp" line="1271"/>
+        <location filename="../widgets/dprintpreviewwidget.cpp" line="1608"/>
+        <location filename="../widgets/dprintpreviewwidget.cpp" line="1611"/>
         <source>Draft</source>
         <translation>草稿</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewwidget.cpp" line="1286"/>
-        <location filename="../widgets/dprintpreviewwidget.cpp" line="1289"/>
+        <location filename="../widgets/dprintpreviewwidget.cpp" line="1626"/>
+        <location filename="../widgets/dprintpreviewwidget.cpp" line="1629"/>
         <source>Sample</source>
         <translation>样本</translation>
     </message>
@@ -559,7 +562,7 @@
 <context>
     <name>DSearchEdit</name>
     <message>
-        <location filename="../widgets/dsearchedit.cpp" line="285"/>
+        <location filename="../widgets/dsearchedit.cpp" line="291"/>
         <source>Search</source>
         <translation>搜索</translation>
     </message>
@@ -598,22 +601,22 @@
 <context>
     <name>DTextEdit</name>
     <message>
-        <location filename="../widgets/dtextedit.cpp" line="155"/>
+        <location filename="../widgets/dtextedit.cpp" line="171"/>
         <source>Stop reading</source>
         <translation>停止朗读</translation>
     </message>
     <message>
-        <location filename="../widgets/dtextedit.cpp" line="157"/>
+        <location filename="../widgets/dtextedit.cpp" line="173"/>
         <source>Text to Speech</source>
         <translation>语音朗读</translation>
     </message>
     <message>
-        <location filename="../widgets/dtextedit.cpp" line="180"/>
+        <location filename="../widgets/dtextedit.cpp" line="196"/>
         <source>Translate</source>
         <translation>翻译</translation>
     </message>
     <message>
-        <location filename="../widgets/dtextedit.cpp" line="202"/>
+        <location filename="../widgets/dtextedit.cpp" line="218"/>
         <source>Speech To Text</source>
         <translation>语音听写</translation>
     </message>
@@ -621,18 +624,11 @@
 <context>
     <name>PickColorWidget</name>
     <message>
-        <location filename="../widgets/dprintpickcolorwidget.cpp" line="89"/>
+        <location filename="../widgets/dprintpickcolorwidget.cpp" line="109"/>
         <source>Color</source>
         <translation>颜色</translation>
     </message>
 </context>
-<context>
-    <name>PrintPreviewDialog</name>
-    <message>
-        <source>Cancel</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>QLineEdit</name>
     <message>
@@ -649,7 +645,7 @@
         <translation>无搜索结果</translation>
     </message>
     <message>
-        <location filename="../widgets/private/settings/content.cpp" line="330"/>
+        <location filename="../widgets/private/settings/content.cpp" line="331"/>
         <source>Restore Defaults</source>
         <translation>恢复默认</translation>
     </message>
@@ -657,7 +653,7 @@
 <context>
     <name>QWidgetTextControl</name>
     <message>
-        <location filename="../widgets/dtextedit.cpp" line="147"/>
+        <location filename="../widgets/dtextedit.cpp" line="163"/>
         <source>Select All</source>
         <translation>全选</translation>
     </message>
@@ -673,37 +669,37 @@
 <context>
     <name>TitleBarMenu</name>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="526"/>
+        <location filename="../widgets/dtitlebar.cpp" line="527"/>
         <source>Theme</source>
         <translation>主题</translation>
     </message>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="528"/>
+        <location filename="../widgets/dtitlebar.cpp" line="529"/>
         <source>Light Theme</source>
         <translation>浅色</translation>
     </message>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="529"/>
+        <location filename="../widgets/dtitlebar.cpp" line="530"/>
         <source>Dark Theme</source>
         <translation>深色</translation>
     </message>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="530"/>
+        <location filename="../widgets/dtitlebar.cpp" line="531"/>
         <source>System Theme</source>
         <translation>跟随系统</translation>
     </message>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="554"/>
+        <location filename="../widgets/dtitlebar.cpp" line="555"/>
         <source>Help</source>
         <translation>帮助</translation>
     </message>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="561"/>
+        <location filename="../widgets/dtitlebar.cpp" line="563"/>
         <source>About</source>
         <translation>关于</translation>
     </message>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="568"/>
+        <location filename="../widgets/dtitlebar.cpp" line="570"/>
         <source>Exit</source>
         <translation>退出</translation>
     </message>
