@@ -399,7 +399,7 @@ void DApplicationPrivate::doAcclimatizeVirtualKeyboard(QWidget *window, QWidget
             activeInputWindow->setContentsMargins(activeInputWindowContentsMargins);
             activeInputWindow = nullptr;
         }
-
+        widget->setProperty("_dtk_selectHandleMargins", 0);
         return;
     }
 
@@ -457,17 +457,22 @@ void DApplicationPrivate::doAcclimatizeVirtualKeyboard(QWidget *window, QWidget
     int resizeHeight = qMin(resizeableHeight, shadowHeight);
     panValue = shadowHeight - resizeHeight;
 
-    if (lastContentsMargins.first == resizeableHeight
-            && lastContentsMargins.second == panValue) {
-        return;
-    }
-
     // 记录本次的计算结果
     lastContentsMargins.first = resizeableHeight;
     lastContentsMargins.second = panValue;
 
+    QRectF cursor = input_method->anchorRectangle();
+    QPointF cursorPoint = cursor.topLeft();
+
+    if (cursorPoint.y() < kRect.y()) {
+        if (window->contentsMargins() != QMargins())
+            window->setContentsMargins(QMargins());
+        return;
+    }
+
     // 更新窗口内容显示区域以确保虚拟键盘能正常显示
     window->setContentsMargins(0, -panValue, 0, resizeHeight + panValue);
+    widget->setProperty("_dtk_selectHandleMargins", panValue);
 }
 
 void DApplicationPrivate::acclimatizeVirtualKeyboardForFocusWidget(bool allowResizeContentsMargins)
@@ -501,8 +506,20 @@ bool DApplicationPrivate::isUserManualExists()
     auto loadManualFromLocalFile = [=]() -> bool {
         const QString appName = qApp->applicationName();
         bool dmanAppExists = QFile::exists("/usr/bin/dman");
-        bool dmanDataExists = QFile::exists("/usr/share/deepin-manual/manual/" + appName) ||
-                              QFile::exists("/app/share/deepin-manual/manual/" + appName);
+        bool dmanDataExists = false;
+        // search all subdirectories
+        QString strManualPath = "/usr/share/deepin-manual";
+        QDirIterator it(strManualPath, QDirIterator::Subdirectories);
+        while (it.hasNext()) {
+            QFileInfo file(it.next());
+            if (file.isDir() && file.fileName().contains(appName, Qt::CaseInsensitive)) {
+                dmanDataExists = true;
+                break;
+            }
+
+            if (file.isDir())
+                continue;
+        }
         return  dmanAppExists && dmanDataExists;
     };
 
@@ -1309,7 +1326,7 @@ void DApplication::setAutoActivateWindows(bool autoActivateWindows)
  */
 void DApplication::acclimatizeVirtualKeyboard(QWidget *window)
 {
-    Q_ASSERT(window->isTopLevel()
+    Q_ASSERT(!window->property("_dtk_NoTopLevelEnabled").toBool() ? window->isTopLevel() : true
              && !window->testAttribute(Qt::WA_LayoutOnEntireRect)
              && !window->testAttribute(Qt::WA_ContentsMarginsRespectsSafeArea));
 
@@ -1384,6 +1401,26 @@ bool DApplication::isAcclimatizedVirtualKeyboard(QWidget *window) const
     return d->acclimatizeVirtualKeyboardWindows.contains(window);
 }
 
+/*!
+   \fn DApplication::customHandler(DAppHandler *handler)
+   \brief 设置 app 的处理程序，如果要设置，必须对 help、about、quit 都进行处理。handler 需要继承实现。
+*/
+void DApplication::setCustomHandler(DAppHandler *handler)
+{
+    D_D(DApplication);
+    d->appHandler = handler;
+}
+
+/*!
+  \fn DApplication::customHandler()
+  \brief 获取设置的 app 定制化处理程序
+*/
+DAppHandler *DApplication::customHandler()
+{
+    D_D(DApplication);
+    return d->appHandler;
+}
+
 /**
  * \~english @brief DApplication::handleHelpAction
  *
@@ -1396,6 +1433,12 @@ bool DApplication::isAcclimatizedVirtualKeyboard(QWidget *window) const
  */
 void DApplication::handleHelpAction()
 {
+    D_D(DApplication);
+    if (customHandler()) {
+        d->appHandler->handleHelpAction();
+        return;
+    }
+
 #ifdef Q_OS_LINUX
     QString appid = applicationName();
 
@@ -1429,9 +1472,19 @@ void DApplication::handleHelpAction()
 void DApplication::handleAboutAction()
 {
     D_D(DApplication);
+    if (customHandler()) {
+        d->appHandler->handleAboutAction();
+        return;
+    }
 
     if (d->aboutDialog) {
-        d->aboutDialog->show();
+        d->aboutDialog->activateWindow();
+        d->aboutDialog->raise();
+        if (DGuiApplicationHelper::isTabletEnvironment()) {
+            d->aboutDialog->exec();
+        } else {
+            d->aboutDialog->show();
+        }
         return;
     }
 
@@ -1448,8 +1501,6 @@ void DApplication::handleAboutAction()
         aboutDialog->setAcknowledgementLink(applicationAcknowledgementPage());
     }
     aboutDialog->setAcknowledgementVisible(d->acknowledgementPageVisible);
-
-    aboutDialog->show();
     aboutDialog->setAttribute(Qt::WA_DeleteOnClose);
 
     //目前的关于对话框是非模态的,这里的处理是防止关于对话框可以打开多个的情况
@@ -1459,6 +1510,12 @@ void DApplication::handleAboutAction()
     connect(d->aboutDialog, &DAboutDialog::destroyed, this, [=] {
         d->aboutDialog = nullptr;
     });
+
+    if (DGuiApplicationHelper::isTabletEnvironment()) {
+        aboutDialog->exec();
+    } else {
+        aboutDialog->show();
+    }
 }
 
 /**
@@ -1474,6 +1531,12 @@ void DApplication::handleAboutAction()
  */
 void DApplication::handleQuitAction()
 {
+    D_D(DApplication);
+    if (customHandler()) {
+        d->appHandler->handleQuitAction();
+        return;
+    }
+
     quit();
 }
 
