@@ -29,6 +29,7 @@
 #include <QAction>
 #include <QRegularExpression>
 #include <DFontSizeManager>
+#include <DApplication>
 
 #include "private/ddialog_p.h"
 
@@ -43,8 +44,14 @@
 
 DWIDGET_BEGIN_NAMESPACE
 
-DDialogPrivate::DDialogPrivate(DDialog *qq) :
-    DAbstractDialogPrivate(qq)
+DDialogPrivate::DDialogPrivate(DDialog *qq)
+    : DAbstractDialogPrivate(qq)
+    , messageLabel(nullptr)
+    , titleLabel(nullptr)
+    , iconLayout(nullptr)
+    , contentLayout(nullptr)
+    , buttonLayout(nullptr)
+    , clickedButtonIndex(0)
 {
 
 }
@@ -104,6 +111,17 @@ void DDialogPrivate::init()
     contentLayout->setSpacing(0);
     contentLayout->addLayout(textLayout);
 
+    contentWidget = new QWidget;
+    contentWidget->setLayout(contentLayout);
+    DApplication *dapp = qobject_cast<DApplication*>(qApp);
+
+    if (dapp) {
+        contentWidget->setAttribute(Qt::WA_LayoutOnEntireRect, false);
+        contentWidget->setAttribute(Qt::WA_ContentsMarginsRespectsSafeArea, false);
+        contentWidget->setProperty("_dtk_NoTopLevelEnabled", true);
+        qApp->acclimatizeVirtualKeyboard(contentWidget);
+    }
+
     titleBar = new DTitlebar();
     titleBar->setAccessibleName("DDialogTitleBar");
     titleBar->setIcon(icon); //设置标题icon
@@ -118,7 +136,7 @@ void DDialogPrivate::init()
 
     // MainLayout--TopLayout
     mainLayout->addWidget(titleBar, 0, Qt::AlignTop);
-    mainLayout->addLayout(contentLayout);
+    mainLayout->addWidget(contentWidget);
     mainLayout->setContentsMargins(QMargins(0, 0, 0, 0));
 
     // MainLayout--ButtonLayout
@@ -230,11 +248,13 @@ void DDialogPrivate::_q_onButtonClicked()
     QAbstractButton *button = qobject_cast<QAbstractButton *>(q->sender());
 
     if (button) {
-        clickedButtonIndex = buttonList.indexOf(button);
-        q->buttonClicked(clickedButtonIndex, button->text());
+        int index = buttonList.indexOf(button);
+        q->buttonClicked(index, button->text());
 
-        if (onButtonClickedClose)
+        if (onButtonClickedClose) {
+            clickedButtonIndex = index;
             q->done(clickedButtonIndex);
+        }
     }
 }
 
@@ -1025,19 +1045,29 @@ void DDialog::setOnButtonClickedClose(bool onButtonClickedClose)
 /*!
  * \~chinese \brief 以模态框形式显示当前对话框
  *
- * \~chinese 以 \l{QDialog#Modal Dialogs}{模态框} 形式显示当前对话框，将会阻塞直到用户关闭对话框，并返回 \DialogCode 结果。
+ * \~chinese 以 \l{QDialog#Modal Dialogs}{模态框} 形式显示当前对话框，将会阻塞直到用户关闭对话框。
+ *
+ * \~chinese onButtonClickedClose()为 true 时返回当前点击按钮的Index，否则返回 \DialogCode 结果。
  *
- * \sa open(), show(), result(), setWindowModality()
  */
 int DDialog::exec()
 {
     D_D(DDialog);
 
     d->clickedButtonIndex = -1;
+    int clickedIndex = d->clickedButtonIndex;
+
+    if (d->onButtonClickedClose) {
+        // 如果设置了WA_DeleteOnClose属性，那么在exec()中将直接delete this
+        // d->clickedButtonIndex中记录的数据失效，这里通过信号槽更新正确的数据
+        connect(this, &DDialog::buttonClicked, this, [ &clickedIndex ] (int index, const QString &) {
+                clickedIndex = index;
+        });
+    }
 
     int code = DAbstractDialog::exec();
 
-    return d->clickedButtonIndex >= 0 ? d->clickedButtonIndex : code;
+    return clickedIndex >= 0 ? clickedIndex : code;
 }
 
 void DDialog::setCloseButtonVisible(bool closeButtonVisible)
