@@ -107,12 +107,12 @@ void DMainWindowPrivate::init()
         }
     }
 
-    if (!help && DApplicationPrivate::isUserManualExists()) {
+    if (!help) {
         help = new QShortcut(QKeySequence(Qt::Key_F1), q);
         QObject::connect(help, &QShortcut::activated,
         q, [ = ]() {
             DApplication *dapp = qobject_cast<DApplication *>(qApp);
-            if (dapp) {
+            if (dapp && DApplicationPrivate::isUserManualExists()) {
                 dapp->handleHelpAction();
             }
         });
@@ -591,8 +591,9 @@ void DMainWindow::setEnableSystemMove(bool enableSystemMove)
 }
 
 /*!
- * \~chinese \brief DMainWindow::setEnableBlurWindow　设定时候能伸缩窗口
- * \~chinese \param enableBlurWindow true能伸缩　false不能伸缩
+ * \~chinese \brief DMainWindow::setEnableBlurWindow　设置窗口模糊效果
+ * \~shinese 开启此功能请设置setAttribute(Qt::WA_TranslucentBackground)
+ * \~chinese \param enableBlurWindow true开启模糊效果　false关闭模糊效果
  */
 void DMainWindow::setEnableBlurWindow(bool enableBlurWindow)
 {
