@@ -525,6 +525,7 @@ void DPrintPreviewWidgetPrivate::updatePageByPagePrintVector(QVector<int> &pageV
             if (isAsynPreview) {
                 for (int i = 0; i <= pic.count() - 1; i++) {
                     for (int j = 1; j < pageCopyCount; j++) {
+                        // cppcheck-suppress arrayIndexOutOfBounds
                         pictures.insert(pictures.indexOf(pic.at(i)), pic.at(i));
                     }
                 }
@@ -532,6 +533,7 @@ void DPrintPreviewWidgetPrivate::updatePageByPagePrintVector(QVector<int> &pageV
             //插入拷贝份数需要打印的页码
             for (int i = 0; i <= vector.count() - 1; i++) {
                 for (int j = 1; j < pageCopyCount; j++) {
+                    // cppcheck-suppress arrayIndexOutOfBounds
                     pageVector.insert(pageVector.indexOf(vector.at(i)), vector.at(i));
                 }
             }
@@ -658,6 +660,7 @@ void DPrintPreviewWidgetPrivate::impositionPages()
 
 int DPrintPreviewWidgetPrivate::impositionPages(DPrintPreviewWidget::Imposition im)
 {
+    Q_UNUSED(im)
     switch (imposition) {
     case DPrintPreviewWidget::One:
         return ONE_PAGE;
@@ -672,6 +675,9 @@ int DPrintPreviewWidgetPrivate::impositionPages(DPrintPreviewWidget::Imposition
     case DPrintPreviewWidget::FourRowFourCol:
         return FOUR_ROW_FOUR_COL_PAGES;
     }
+
+    qWarning() << "DPrintPreviewWidget::Imposition enumeration value is out of range";
+    return -1;
 }
 
 QImage DPrintPreviewWidgetPrivate::generateWaterMarkImage() const
@@ -2013,9 +2019,9 @@ void DPrintPreviewWidget::themeTypeChanged(DGuiApplicationHelper::ColorType them
 {
     Q_D(DPrintPreviewWidget);
     if (DGuiApplicationHelper::DarkType == themeType)
-        d->scene->setBackgroundBrush(QColor(0, 0, 0, 3));
+        d->graphicsView->setBackgroundBrush(QColor(0, 0, 0, 42));
     else
-        d->scene->setBackgroundBrush(QColor(255, 255, 255, 5));
+        d->graphicsView->setBackgroundBrush(QColor(255, 255, 255, 120));
 }
 
 DPrinter::DPrinter(QPrinter::PrinterMode mode)
