@@ -27,6 +27,7 @@
 #include <DWindowManagerHelper>
 #include <DObjectPrivate>
 #include <DPlatformTheme>
+#include <QScreen>
 
 #include "dwindowclosebutton.h"
 #include "dwindowmaxbutton.h"
@@ -133,7 +134,9 @@ private:
     Q_DECLARE_PUBLIC(DTitlebar)
 };
 
-DTitlebarPrivate::DTitlebarPrivate(DTitlebar *qq): DObjectPrivate(qq)
+DTitlebarPrivate::DTitlebarPrivate(DTitlebar *qq)
+    : DObjectPrivate(qq)
+    , quitFullButton(nullptr)
 {
 }
 
@@ -160,7 +163,6 @@ void DTitlebarPrivate::init()
         optionButton = new DWindowOptionButton;
     }
 
-    quitFullButton  = new DWindowQuitFullButton;
     separatorTop    = new DHorizontalLine(q);
     separator       = new DHorizontalLine(q);
     titleLabel      = centerArea;
@@ -170,7 +172,6 @@ void DTitlebarPrivate::init()
     maxButton->installEventFilter(q);
     closeButton->installEventFilter(q);
     optionButton->installEventFilter(q);
-    quitFullButton->installEventFilter(q);
 
     optionButton->setObjectName("DTitlebarDWindowOptionButton");
     optionButton->setIconSize(QSize(DefaultTitlebarHeight, DefaultTitlebarHeight));
@@ -184,10 +185,7 @@ void DTitlebarPrivate::init()
     closeButton->setObjectName("DTitlebarDWindowCloseButton");
     closeButton->setAccessibleName("DTitlebarDWindowCloseButton");
     closeButton->setIconSize(QSize(DefaultTitlebarHeight, DefaultTitlebarHeight));
-    quitFullButton->setObjectName("DTitlebarDWindowQuitFullscreenButton");
-    quitFullButton->setAccessibleName("DTitlebarDWindowQuitFullscreenButton");
-    quitFullButton->setIconSize(QSize(DefaultTitlebarHeight, DefaultTitlebarHeight));
-    quitFullButton->hide();
+
 
     iconLabel->setIconSize(QSize(DefaultIconWidth, DefaultIconHeight));
     iconLabel->setWindowFlags(Qt::WindowTransparentForInput);
@@ -220,7 +218,15 @@ void DTitlebarPrivate::init()
     buttonLayout->addWidget(optionButton);
     buttonLayout->addWidget(minButton);
     buttonLayout->addWidget(maxButton);
-    buttonLayout->addWidget(quitFullButton);
+    if (!DGuiApplicationHelper::isTabletEnvironment()) {
+        quitFullButton  = new DWindowQuitFullButton;
+        quitFullButton->installEventFilter(q);
+        quitFullButton->setObjectName("DTitlebarDWindowQuitFullscreenButton");
+        quitFullButton->setAccessibleName("DTitlebarDWindowQuitFullscreenButton");
+        quitFullButton->setIconSize(QSize(DefaultTitlebarHeight, DefaultTitlebarHeight));
+        quitFullButton->hide();
+        buttonLayout->addWidget(quitFullButton);
+    }
     buttonLayout->addWidget(closeButton);
 
     rightArea->setWindowFlag(Qt::WindowTransparentForInput);
@@ -252,14 +258,16 @@ void DTitlebarPrivate::init()
     q->setFixedHeight(DefaultTitlebarHeight);
     q->setMinimumHeight(DefaultTitlebarHeight);
 
-    q->connect(quitFullButton, &DWindowQuitFullButton::clicked, q, [ = ]() {
-        bool isFullscreen = targetWindow()->windowState().testFlag(Qt::WindowFullScreen);
-        if (isFullscreen) {
-            targetWindow()->showNormal();
-        } else {
-            targetWindow()->showFullScreen();
-        }
-    });
+    if (!DGuiApplicationHelper::isTabletEnvironment()) {
+        q->connect(quitFullButton, &DWindowQuitFullButton::clicked, q, [ = ]() {
+            bool isFullscreen = targetWindow()->windowState().testFlag(Qt::WindowFullScreen);
+            if (isFullscreen) {
+                targetWindow()->showNormal();
+            } else {
+                targetWindow()->showFullScreen();
+            }
+        });
+    }
     q->connect(optionButton, &DIconButton::clicked, q, &DTitlebar::optionClicked);
     q->connect(DWindowManagerHelper::instance(), SIGNAL(windowMotifWMHintsChanged(quint32)),
                q, SLOT(_q_onTopWindowMotifHintsChanged(quint32)));
@@ -267,6 +275,8 @@ void DTitlebarPrivate::init()
         iconLabel->update();
     });
 
+    // 默认需要构造一个空的选项菜单
+    q->setMenu(new QMenu(q));
     q->setFrameShape(QFrame::NoFrame);
     q->setBackgroundRole(QPalette::Base);
     q->setAutoFillBackground(true);
@@ -320,12 +330,14 @@ void DTitlebarPrivate::updateFullscreen()
     bool isFullscreen = targetWindow()->windowState().testFlag(Qt::WindowFullScreen);
     auto mainWindow = qobject_cast<DMainWindow *>(targetWindow());
     if (!isFullscreen) {
-        quitFullButton->hide();
+        if (!DGuiApplicationHelper::isTabletEnvironment())
+            quitFullButton->hide();
         mainWindow->setMenuWidget(q);
         showOnFullscreen();
     } else {
         // must set to empty
-        quitFullButton->show();
+        if (!DGuiApplicationHelper::isTabletEnvironment())
+            quitFullButton->show();
         if (mainWindow->menuWidget()) {
             mainWindow->menuWidget()->setParent(nullptr);
             mainWindow->setMenuWidget(Q_NULLPTR);
@@ -349,7 +361,7 @@ void DTitlebarPrivate::updateButtonsState(Qt::WindowFlags type)
     forceShow = false;
 #endif
 
-    bool showTitle = (type.testFlag(Qt::WindowTitleHint) || forceShow) && !embedMode && !DGuiApplicationHelper::isTabletEnvironment();
+    bool showTitle = (type.testFlag(Qt::WindowTitleHint) || forceShow) && !embedMode;
     if (titleLabel) {
         if (showTitle) {
             titleLabel->setText(q->property("_dtk_title").toString());
@@ -377,7 +389,9 @@ void DTitlebarPrivate::updateButtonsState(Qt::WindowFlags type)
     bool showQuit = isFullscreen && useDXcb && fullScreenButtonVisible;
     maxButton->setVisible(showMax);
     closeButton->setVisible(showClose);
-    quitFullButton->setVisible(showQuit);
+
+    if (!DGuiApplicationHelper::isTabletEnvironment())
+        quitFullButton->setVisible(showQuit);
     //    qDebug() << "max:"
     //             << "allowResize" << allowResize
     //             << "useDXcb" << useDXcb
@@ -521,10 +535,6 @@ void DTitlebarPrivate::_q_addDefaultMenuItems()
 {
     D_Q(DTitlebar);
 
-    if (!menu) {
-        q->setMenu(new QMenu(q));
-    }
-
     // add switch theme sub menu
     if (!switchThemeMenu) {
         bool disableDtkSwitchThemeMenu = qEnvironmentVariableIsSet("KLU_DISABLE_MENU_THEME");
@@ -551,15 +561,17 @@ void DTitlebarPrivate::_q_addDefaultMenuItems()
             themeSeparator = menu->addSeparator();
 
             switchThemeMenu->menuAction()->setVisible(canSwitchTheme);
-            themeSeparator->setVisible(canSwitchTheme);
+
+            themeSeparator->setVisible(DGuiApplicationHelper::isTabletEnvironment() ? false : canSwitchTheme);
         }
     }
 
     // add help menu item.
-    if (!helpAction && DApplicationPrivate::isUserManualExists()) {
+    if (!helpAction) {
         helpAction = new QAction(qApp->translate("TitleBarMenu", "Help"), menu);
         QObject::connect(helpAction, SIGNAL(triggered(bool)), q, SLOT(_q_helpActionTriggered()));
         menu->addAction(helpAction);
+        helpAction->setVisible(false);
     }
 
     // add about menu item.
@@ -573,7 +585,9 @@ void DTitlebarPrivate::_q_addDefaultMenuItems()
     if (!quitAction) {
         quitAction = new QAction(qApp->translate("TitleBarMenu", "Exit"), menu);
         QObject::connect(quitAction, SIGNAL(triggered(bool)), q, SLOT(_q_quitActionTriggered()));
-        menu->addAction(quitAction);
+        if (!DGuiApplicationHelper::isTabletEnvironment()) {
+            menu->addAction(quitAction);
+        }
     }
 }
 
@@ -742,6 +756,15 @@ void DTitlebar::setMenu(QMenu *menu)
         d->menu->setAccessibleName("DTitlebarMainMenu");
         disconnect(this, &DTitlebar::optionClicked, 0, 0);
         connect(this, &DTitlebar::optionClicked, this, &DTitlebar::showMenu);
+
+        if (DGuiApplicationHelper::isTabletEnvironment()) {
+            if (QScreen *screen = QGuiApplication::primaryScreen()) {
+                disconnect(screen, &QScreen::primaryOrientationChanged, this, 0);
+                connect(screen, &QScreen::primaryOrientationChanged, this, [ = ] {
+                    d->menu->move(d->optionButton->mapToGlobal(d->optionButton->rect().bottomLeft()));
+                });
+            }
+        }
     }
 }
 
@@ -781,6 +804,13 @@ void DTitlebar::showMenu()
 {
     D_D(DTitlebar);
 
+#ifndef QT_NO_MENU
+    // 默认菜单应该是showmenu之前添加, 而非showevent
+    d->_q_addDefaultMenuItems();
+#endif
+     if (d->helpAction)
+         d->helpAction->setVisible(DApplicationPrivate::isUserManualExists());
+
     if (d->menu) {
         // 更新主题选中的项
         if (d->switchThemeMenu) {
@@ -816,10 +846,6 @@ void DTitlebar::showEvent(QShowEvent *event)
     d->separator->setFixedWidth(width());
     d->separator->move(0, height() - d->separator->height());
 
-#ifndef QT_NO_MENU
-    d->_q_addDefaultMenuItems();
-#endif
-
     QWidget::showEvent(event);
 
     if (DPlatformWindowHandle::isEnabledDXcb(window())) {
